#!/bin/sh

#  Codec-Info.command
#  
#
#  Created by Rodion Shingarev on 03/03/15.
#
# User Defined
Native="0x11d4198b"

# if HDEF
HDEF=$(ioreg -rw 0 -p IODeviceTree -n HDEF | grep -o "HDEF@")
if [ ${HDEF:0:5} == "HDEF@" ]
then
HDEF=$(ioreg -rw 0 -p IODeviceTree -n HDEF | awk '{ print $2 }' )
echo $HDEF
else
echo "ERROR: No HDEF Device found in DSDT"
exit 1
fi

VendorID=($(ioreg -rxn IOHDACodecDevice | grep VendorID | awk '{ print $4 }' ))
RevisionID=($(ioreg -rxn IOHDACodecDevice | grep RevisionID | awk '{ print $4 }'))
CodecAddress=($(ioreg -rxn IOHDACodecDevice | grep IOHDACodecAddress | awk '{ print $4 }'))
PinConfigurations=$(ioreg -rw 0 -p IODeviceTree -n HDEF | grep PinConfigurations | awk '{ print $3 }' | sed -e 's/.*<//' -e 's/>//')
layout_id=$(ioreg -rw 0 -p IODeviceTree -n HDEF | grep layout-id | sed -e 's/.*<//' -e 's/>//')
layout_id="0x${layout_id:6:2}${layout_id:4:2}${layout_id:2:2}${layout_id:0:2}"
let Layout=$layout_id
echo "Layout, hex:" $layout_id ", dec:" $Layout
echo
echo "PinConfigurations:"
echo $PinConfigurations

N=${#VendorID[@]}
echo
echo "Codecs Found:" $N
N=$(($N-1))
for i in $(seq 0 $N)
do
if [[ ${VendorID[$i]} == *"1002"* ]] || [[ ${VendorID[$i]} == *"10de"* ]] || [[ ${VendorID[$i]} == *"8086"* ]]
then
echo "HDMI:"
HDAU=$i
let CodecID=${VendorID[$HDAU]}
echo $HDAU "CodecAddress:"${CodecAddress[$HDAU]}
echo "VendorID:" ${VendorID[$HDAU]}
echo "RevisionID:" ${RevisionID[$HDAU]}
echo "CodecID:" $CodecID
echo
else
echo "HDA:"
HDEF=$i
let CodecID=${VendorID[$HDEF]}
echo $HDEF "CodecAddress:"${CodecAddress[$HDEF]}
echo "VendorID:" ${VendorID[$HDEF]}
echo "RevisionID:" ${RevisionID[$HDEF]}
echo "CodecID:" $CodecID
var1=${VendorID[$HDEF]}
let Revisiond=${RevisionID[$HDEF]}
echo "Revision(dec):"=$Revisiond
id="0x${var1:6:4}"
ven="0x${var1:2:4}"
echo "Id="$id
let idd=${id}
echo "Id(dec)="$idd
echo "Vendor="$ven
let vend=${ven}
echo "Vendor(dec)="$vend
echo

rm -rf ~/Desktop/Info.plist
rm -rf Patch.plist

Patch=${VendorID[$HDEF]}
PathMapID=${VendorID[$HDEF]}
PathMapID=${PathMapID:6:4}
PathMapID=$(echo $PathMapID | sed 's/^0*//')
PathMapID="${PathMapID/198b/1988}"
PathMapID="${PathMapID/989b/1989}"

/usr/libexec/PlistBuddy -c "Add :Author string"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Set :Author $(whoami)"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :CodecName string"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Set :CodecName ${VendorID[$HDEF]} Rev:${RevisionID[$HDEF]}"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :CodecID integer"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Set :CodecID $idd"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Files dict"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Files:Layouts array"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Files:Layouts:0 dict"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Files:Layouts:0:Id integer"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Set :Files:Layouts:0:Id $Layout"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Files:Layouts:0:Path string"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Set :Files:Layouts:0:Path layout$Layout.xml.zlib"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Files:Platforms array"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Files:Platforms:0 dict"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Files:Platforms:0:Id integer"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Set :Files:Platforms:0:Id $Layout"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Files:Platforms:0:Path string"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Set :Files:Platforms:0:Path Platforms.xml.zlib"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Revisions array"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Revisions:0 integer"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Set :Revisions:0 $Revisiond"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Add :Patches array"  ~/Desktop/Info.plist

N=0

/usr/libexec/PlistBuddy -c "Add :Patches:$N dict"  ~/Desktop/Info.plist
defaults write ~/Patch.plist Find -data 8319D411
defaults write ~/Patch.plist Replace -data 00000000
defaults write ~/Patch.plist Name -string "AppleHDA"
defaults write ~/Patch.plist MinKernel -int 15
defaults write ~/Patch.plist Count -int 2
/usr/libexec/PlistBuddy -c "Merge Patch.plist :Patches:$N" ~/Desktop/Info.plist

if [ $Patch != "0x10ec0885" ] && [ $Patch != "0x11d4198b" ] && [ $Patch != "0x11d41984" ] && [ $Patch != $Native ]
then
N=$N+1
Patch=${Patch:8:2}${Patch:6:2}${Patch:4:2}${Patch:2:2}
Native=${Native:8:2}${Native:6:2}${Native:4:2}${Native:2:2}
defaults write ~/Patch.plist Find -data $Native
defaults write ~/Patch.plist Replace -data $Patch
defaults write ~/Patch.plist MinKernel -int 13
/usr/libexec/PlistBuddy -c "Add :Patches:$N dict"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Merge Patch.plist :Patches:$N" ~/Desktop/Info.plist
fi

if  (( $PathMapID < 885 ))
then
N=$N+1
defaults write ~/Patch.plist Find -data 8408ec10
defaults write ~/Patch.plist Replace -data 00000000
defaults write ~/Patch.plist MinKernel -int 13
/usr/libexec/PlistBuddy -c "Add :Patches:$N dict"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Merge Patch.plist :Patches:$N" ~/Desktop/Info.plist
N=$N+1
defaults write ~/Patch.plist Find -data 8508ec10
defaults write ~/Patch.plist Replace -data 00000000
defaults write ~/Patch.plist MinKernel -int 13
/usr/libexec/PlistBuddy -c "Add :Patches:$N dict"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Merge Patch.plist :Patches:$N" ~/Desktop/Info.plist
fi

N=$N+1
defaults write ~/Patch.plist Find -data 41c6864301000000
defaults write ~/Patch.plist Replace -data 41c6864301000001
defaults write ~/Patch.plist MinKernel -int 13
defaults write ~/Patch.plist Count -int 1
/usr/libexec/PlistBuddy -c "Add :Patches:$N dict"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Merge Patch.plist :Patches:$N" ~/Desktop/Info.plist
N=$N+1
defaults write ~/Patch.plist Find -data 41c60600488bbb68
defaults write ~/Patch.plist Replace -data 41c60601488bbb68
defaults write ~/Patch.plist MinKernel -int 14
defaults write ~/Patch.plist Count -int 1
/usr/libexec/PlistBuddy -c "Add :Patches:$N dict"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Merge Patch.plist :Patches:$N" ~/Desktop/Info.plist
N=$N+1
defaults write ~/Patch.plist Find -data 41c60600498bbc24
defaults write ~/Patch.plist Replace -data 41c60601498bbc24
defaults write ~/Patch.plist MinKernel -int 13
defaults write ~/Patch.plist MaxKernel -int 13
defaults write ~/Patch.plist Count -int 1
/usr/libexec/PlistBuddy -c "Add :Patches:$N dict"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Merge Patch.plist :Patches:$N" ~/Desktop/Info.plist

rm -rf Patch.plist

/usr/libexec/PlistBuddy -c "Add :Vendor string"  ~/Desktop/Info.plist
/usr/libexec/PlistBuddy -c "Set :Vendor Unknown"  ~/Desktop/Info.plist
case $ven in
"0x11d4")
/usr/libexec/PlistBuddy -c "Set :Vendor AnalogDevices"  ~/Desktop/Info.plist
;;
"0x10ec")
/usr/libexec/PlistBuddy -c "Set :Vendor Realtek"  ~/Desktop/Info.plist
;;
esac




#Patch=${VendorID[$HDEF]}
#Patch=${Patch:8:2}${Patch:6:2}${Patch:4:2}${Patch:2:2}
#Native=${Native:8:2}${Native:6:2}${Native:4:2}${Native:2:2}
#echo "Replace Patch="$Patch
#/usr/libexec/PlistBuddy -c "Set :Patches:0:Replace 0009EC10"  ~/Desktop/Info.plist  id -un


fi
done



